==> rspamd_0.6.10.tar.xz: rspamd-0.6.10/doc/rspamd.8.md <==
% RSPAMD(8) Rspamd User Manual

# NAME

rspamd - main daemon for rapid spam filtering system

# SYNOPSIS

rspamd [*options*]...

rspamd \--help

# DESCRIPTION

Rspamd filtering system is designed to be fast, modular and easily scalable system. 
Rspamd core is written in `C` language using event driven processing model. 
Plugins for rspamd can be written in `Lua` programming language.
Rspamd is designed to process connections completely asynchronous and do not block anywhere in code.

# OPTIONS

-t, \--config-test
:	Perform config test and exit

-f, \--no-fork
:	Do not daemonize main process

-c *path*, \--config=*path*
:	Specify config file(s)

-u *username*, \--user=*username*
:	User to run rspamd as

-g *groupname*, \--group=*groupname*
:	Group to run rspamd as

-p *path*, \--pid=*path*
:	Path to pidfile

-C, \--dump-cache
:	Dump symbols cache stats and exit

-d, \--debug
:	Force debug output

-i, \--insecure
:	Ignore running workers as privileged users (insecure)

\--test-lua=*path*
:	Specify lua file(s) to test

\--sign-config=*path*
:	Specify config file(s) to sign

\--private-key=*path*
:	Specify private key to sign

\--convert-config=*path*
:	Convert configuration to UCL

# EXAMPLES

Run rspamd daemon with default configuration:

	rspamd
	
Run rspamd in foreground with custom configuration:

	rspamd \-f \-c ~/rspamd.conf
	
Run rspamd specifying user and group:

	rspamd \-u rspamd \-g rspamd \-c /etc/rspamd/rspamd.conf

Test lua scripts using rspamd API:

	rspamd \-\-test-lua=~/test1.lua \-\-test-lua=~/test2.lua

Sign config files for `.includes` macro:

	rspamd \-\-private-key=sign.key \-\-sign-config=rspamd.conf

Convert old `XML` config to the `UCL` format (since 0.6.0):

	rspamd \-c /etc/rspamd.xml \-\-convert-config=/etc/rspamd/rspamd.conf

# SEE ALSO

Rspamd documentation and source codes may be downloaded from
<https://rspamd.com/>.

==> rspamd-0.8.3.tar.xz: rspamd-0.8.3/doc/rspamd.8.md <==
% RSPAMD(8) Rspamd User Manual

# NAME

rspamd - main daemon for rapid spam filtering system

# SYNOPSIS

rspamd [*options*]...

rspamd --help

# DESCRIPTION

Rspamd filtering system is designed to be fast, modular and easily scalable system. 
Rspamd core is written in `C` language using event driven processing model. 
Plugins for rspamd can be written in `Lua` programming language.
Rspamd is designed to process connections completely asynchronous and do not block anywhere in code.

# OPTIONS

-t, \--config-test
:	Perform config test and exit

-f, \--no-fork
:	Do not daemonize main process

-c *path*, \--config=*path*
:	Specify config file(s)

-u *username*, \--user=*username*
:	User to run rspamd as

-g *groupname*, \--group=*groupname*
:	Group to run rspamd as

-p *path*, \--pid=*path*
:	Path to pidfile

-C, \--dump-cache
:	Dump symbols cache stats and exit

-d, \--debug
:	Force debug output

-i, \--insecure
:	Ignore running workers as privileged users (insecure)

\--test-lua=*path*
:	Specify lua file(s) to test

\--sign-config=*path*
:	Specify config file(s) to sign

\--private-key=*path*
:	Specify private key to sign


# EXAMPLES

Run rspamd daemon with default configuration:

	rspamd
	
Run rspamd in foreground with custom configuration:

	rspamd -f -c ~/rspamd.conf
	
Run rspamd specifying user and group:

	rspamd -u rspamd -g rspamd -c /etc/rspamd/rspamd.conf

Test lua scripts using rspamd API:

	rspamd --test-lua=~/test1.lua --test-lua=~/test2.lua

Sign config files for `.includes` macro:

	rspamd --private-key=sign.key --sign-config=rspamd.conf

# SEE ALSO

Rspamd documentation and source codes may be downloaded from
<https://rspamd.com/>.
